package com.qmth.digit.print.business.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.qmth.digit.print.business.bean.dto.BlurryUserDto;
import com.qmth.digit.print.business.bean.dto.ExamTaskDto;
import com.qmth.digit.print.business.bean.query.BlurryParam;
import com.qmth.digit.print.business.bean.query.ExamTaskParam;
import com.qmth.digit.print.business.entity.ExamTask;
import com.qmth.digit.print.business.mapper.ExamTaskMapper;
import com.qmth.digit.print.business.service.ExamTaskService;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 命题任务 服务实现类
 * </p>
 *
 * @author xf
 * @since 2021-03-23
 */
@Service
public class ExamTaskServiceImpl extends ServiceImpl<ExamTaskMapper, ExamTask> implements ExamTaskService {

    @Override
    public List<ExamTask> listByCourseCode(Long schoolId, String code) {
        QueryWrapper<ExamTask> queryWrapper = new QueryWrapper<>();
        queryWrapper.lambda().eq(ExamTask::getSchoolId, schoolId).eq(ExamTask::getCourseCode, code);
        return this.list(queryWrapper);
    }

    @Override
    public IPage<ExamTaskDto> list(ExamTaskParam param) {
        Page<ExamTaskDto> page = new Page<>(param.getPageNumber(), param.getPageSize());
        IPage<ExamTaskDto> examTaskDtoIPage = this.baseMapper.listPage(page, param);
        return examTaskDtoIPage;
    }

    @Override
    public List<String> listPaperNumber(BlurryParam param) {
        QueryWrapper<ExamTask> queryWrapper = new QueryWrapper<>();
        List<String> list = new ArrayList<>();
        if (StringUtils.isNotBlank(param.getParam())) {
            queryWrapper.lambda().eq(ExamTask::getSchoolId, param.getSchoolId())
                    .and(i -> i.like(ExamTask::getCourseCode, param.getParam()).or().like(ExamTask::getCourseName, param.getParam()));
        }
        List<ExamTask> examTasks = this.list(queryWrapper);
        if (examTasks != null && examTasks.size() > 0) {
            list = examTasks.stream().map(m -> m.getPaperNumber()).distinct().collect(Collectors.toList());
        }
        return list;
    }

    @Override
    public List<BlurryUserDto> listUser(BlurryParam param) {
        return this.baseMapper.listUser(param);
    }
}
